@@ -7,6 +7,18 @@ class CerndbLoggerException(Exception):
     """Raised when the logger couldn't be initialized."""
 
 
+# These values are used if the config file is missing them
+# or not readable
+DEFAULTS = {
+    "level": "INFO",
+    "file": "/var/log/cerndb.log",
+    "fmt": "%(asctime)s [%(module)s:%(lineno)d][%(process)s] " +
+           "%(levelname)s {0} %(message)s",
+    "datefmt": '%Y-%m-%dT%H:%M:%S%z',
+    "console_logging": False,
+}
+
+
 def setup_root_logger(config=None, tag: str = None):
     """Prepare a root logger.
 
@@ -22,42 +34,29 @@ def setup_root_logger(config=None, tag: str = None):
     # Auto-reinitialize the logger if --debug provided
     config.register_on_change(setup_root_logger)
 
-    # These values are used if the config file is missing them
-    # or not readable
-
-    defaults = {
-        "level": "INFO",
-        "file": "/var/log/cerndb.log",
-        "fmt": "%(asctime)s [%(module)s:%(lineno)d][%(process)s] " +
-               "%(levelname)s {0} %(message)s",
-        "datefmt": '%Y-%m-%dT%H:%M:%S%z'
-    }
-
-    # Fallback to defaults if the values are not in the config file
+    # Fallback to DEFAULTS if the values are not in the config file
     try:
         log_conf = config["log"]
-    except KeyError:
-        # log key not defined in the config file
-        log_conf = defaults
-
-    log_level = log_conf.get("level", defaults["level"])
-    log_file = log_conf.get("file", defaults["file"])
-    log_datefmt = log_conf.get("datefmt", defaults["datefmt"])
+    except (TypeError, KeyError):
+        # TypeError: no config defined
+        # KeyError: log key not defined in the provided config
+        log_conf = DEFAULTS
 
+    log_level = log_conf.get("level", DEFAULTS["level"])
+    log_file = log_conf.get("file", DEFAULTS["file"])
+    log_to_console = log_conf.get("console_logging",
+                                  DEFAULTS['console_logging'])
     # Prioritize a tag provided via arguments over configuration file and
     # default values
-    config_tag = log_conf.get("tag", "CERNDB")
     if tag:
         log_tag = tag
     else:
-        log_tag = config_tag
-
-    log_fmt = log_conf.get("fmt", defaults["fmt"]).format(log_tag)
+        log_tag = log_conf.get("tag", "CERNDB")
 
     if log_level not in ["INFO", "ERROR", "WARNING", "CRITICAL", "DEBUG"]:
         raise CerndbLoggerException(
             f"Incorrect level '{log_level}' in the config "
-            "file {config.used_file}.")
+            f"file {config.used_file}.")
 
     root_logger = logging.getLogger()
     # To prevent double messages if before importing logging.* was used
@@ -67,11 +66,18 @@ def setup_root_logger(config=None, tag: str = None):
 
     root_logger.setLevel(log_level)
 
+    # Configure formatter
+    log_fmt = log_conf.get("fmt", DEFAULTS["fmt"]).format(log_tag)
+    log_datefmt = log_conf.get("datefmt", DEFAULTS["datefmt"])
     formatter = logging.Formatter(log_fmt, log_datefmt)
-    console_handler = logging.StreamHandler()
-    console_handler.setFormatter(formatter)
-    root_logger.addHandler(console_handler)
 
+    # Add console logging if enabled. Disabled by default
+    if log_to_console or log_level == "DEBUG":
+        console_handler = logging.StreamHandler()
+        console_handler.setFormatter(formatter)
+        root_logger.addHandler(console_handler)
+
+    # Configure file based logger
     try:
         file_handler = logging.FileHandler(log_file)
         file_handler.setFormatter(formatter)
